#
# spec file for package opencc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           opencc
Version:        1.1.7
Release:        2.1
Summary:        Open Chinese Convert
License:        Apache-2.0
Group:          System/I18n/Chinese
URL:            https://github.com/BYVoid/OpenCC
Source:         https://github.com/BYVoid/OpenCC/archive/ver.%{version}/OpenCC-ver.%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  rapidjson-devel
# needed to generate some docu files
BuildRequires:  python3-base

%description
OpenCC is an opensource project for conversion between Traditional
Chinese and Simplified Chinese, which supports phrase-level conversion
and regional idioms among Mainland China, Taiwan and Hong kong.

%package -n libopencc1_1
Summary:        Open Chinese Convert
Group:          System/Libraries
Requires:       %{name}-data

%description -n libopencc1_1
OpenCC is an opensource project for conversion between Traditional
Chinese and Simplified Chinese, which supports phrase-level conversion
and regional idioms among Mainland China, Taiwan and Hong kong.

This package provides shared libraries of OpenCC.

%package data
Summary:        Dictionaries for Open Chinese Convert
Group:          System/I18n/Chinese

%description data
OpenCC is an opensource project for conversion between Traditional
Chinese and Simplified Chinese, which supports phrase-level conversion
and regional idioms among Mainland China, Taiwan and Hong kong.

This package provides dictionaries and patterns used by libraries/
binaries of OpenCC.

%package devel
Summary:        Open Chinese Convert
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
OpenCC is an opensource project for conversion between Traditional
Chinese and Simplified Chinese, which supports phrase-level conversion
and regional idioms among Mainland China, Taiwan and Hong kong.

This package provides development headers for OpenCC.

%prep
%setup -q -n OpenCC-ver.%{version}
# call python3 with path
sed -i \
    -e 's:BIN python:BIN /usr/bin/python3:g' \
    data/CMakeLists.txt

%build
%cmake \
  -DCMAKE_SKIP_RPATH=OFF \
  -DUSE_SYSTEM_RAPIDJSON=ON
%make_jobs

%install
%cmake_install
find %{buildroot} -name "*.a" -delete -print

%post -n libopencc1_1 -p /sbin/ldconfig
%postun -n libopencc1_1 -p /sbin/ldconfig

%files
%license LICENSE
%doc AUTHORS NEWS.md README.md
%{_bindir}/%{name}
%{_bindir}/%{name}_dict
%{_bindir}/%{name}_phrase_extract

%files data
%{_datadir}/%{name}/

%files -n libopencc1_1
%{_libdir}/libopencc.so.1.1
%{_libdir}/libopencc.so.%{version}

%files devel
%{_includedir}/%{name}/
%{_libdir}/libopencc.so
%{_libdir}/cmake/opencc
%{_libdir}/pkgconfig/opencc.pc

%changelog
* Fri May 24 2024 Marguerite Su <i@marguerite.su>
- switch to system rapidjson, fix boo#1221875
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.7:
  * Added python package rebuild on commit to verify package
    generation (#822).
  * Support Python 3.12 and Node 20, remove builds for Python 3.7
    and Node 16 (#820).
  * Add support of CMake config modules (#763).
  * Several other minor fixes.
- drop fix-soversion.patch (obsolete)
* Sun Dec 11 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.6:
  * FTBFS for MacOS w/ Python 3.11
  * Support Python 3.11
  * Automatically name SO files
  * Add support for Apple silicon build tag
  * other minor fixes
* Mon Aug  1 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.4:
  * Add python 3.10 support
  * remove support for python < 3.7 and node 10.x
  * small bugfixes
- add fix-soversion.patch for fixing the leftover .so version tag
* Mon Feb 14 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.3:
  * Fix some header files cannot be used alone (#550).
  * Fix the method of introducing system pybind11 (#566).
  * Support Node.js 16 (#597).
  * Support Python 3.9 (#603).
  * Fixed conversion errors.
  * Several other small fixes.
* Fri Mar 12 2021 Dirk Müller <dmueller@suse.com>
- update to 1.1.2:
  * Added Hong Kong Traditional Chinese conversion.
  * Fix the compilation compatibility problem, including parallel compilation.
  * Fixed the serious performance degradation problem introduced since 1.1.0.
- drop opencc-1.1.1-missing-builtin-types.patch: upstream
* Mon Sep 28 2020 Marguerite Su <i@marguerite.su>
- add opencc-1.1.1-missing-builtin-types.patch
  * SimpleConverter.hpp missed "#include <string>" that breaks pyzy
* Sat Sep 12 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.1.1
  * Officially provide interface and TypeScript type annotations.
  * Update the dynamic link library `SOVERSION` to `1.1`, due to
  changes in the internal interface of C++.
  * Simplify the header file structure and speed up compilation. Remove
  unnecessary `using`.  Repair some Hong Kong standard characters.
  * The new dictionary format `ocd2`, based on Marisa Trie 0.2.5. The
  dictionary size is greatly reduced.
  * Change the default conversion of "Yong/Yong" and modify multiple
  phrase conversions.
  * Add benchmark test results.
  * Officially supports Japanese new font conversion.
  * Upgrade Node.js dependency and improve compatibility.
  * Fix multiple multi-platform compilation and compatibility issues.
  * Correct a large number of conversion errors.
* Wed Jan  3 2018 tchvatal@suse.com
- Use python3 for all the operations do not implicitely inherit py2
* Thu Nov  2 2017 mpluskal@suse.com
- Cleanup spec file a bit
- Use more of cmake macros
* Thu Oct  5 2017 hillwood@opensuse.org
- Update to 1.0.5
  * Fix link error for mingw
  * Try fix error nodejs_version=4; Platform: x86
  * Add support for node stable && remove v0.12
  * Update artifacts
  * Artifacts for appveyor
* Sat Mar 12 2016 i@marguerite.su
- update version 1.0.3.1
* Wed Aug 12 2015 i@marguerite.su
- update version 1.0.3
* Sun Feb 15 2015 hillwood@linuxfans.org
- Update to 1.0.2
  * Update dictionary
  * Fix scripts compatibility for Python3
  * Fix compatibility with Python3
  * Add non-allocation interface
  * Add Values() to DictEntry for convinience
  * Fix `OPENCC_DEFAULT_CONFIG_SIMP_TO_TRAD`
* Tue Jul  2 2013 i@marguerite.su
- update version 0.4.3
  * add interface: `opencc_convert_utf8_free`
  * fix memeory leak problem for nodejs plugin
* Mon Nov  5 2012 i@marguerite.su
- split a data package to be required by library.
  fix a conversion crash bug in fcitx.
* Sun Jun 24 2012 i@marguerite.su
- fix fedora builds.
* Sun Jun  3 2012 i@marguerite.su
- fix sles builds.
* Thu Feb 16 2012 coolo@suse.com
- trigger the service so it's true
* Mon Jan 23 2012 i@marguerite.su
- initial package 0.3.0
